/************************************************************************
 *   IRC - Internet Relay Chat, m_core/m_channelts.c
 *   This file is copyright (C) 2001 Andrew Suffield
 *                                    <asuffield@users.sourceforge.net>
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 */

#include "ircd.h"
#include "common.h"
#include "numeric.h"
#include "irc_string.h"
#include "send.h"
#include "umodes.h"
#include "msg.h"
#include "handlers.h"
#include "channel.h"
#include "client.h"
#include "burst.h"

#include <stdlib.h>

int m_channelts(struct Client *, struct Client *, int, char **);

struct Message channelts_msgtab = {
  "CHANNELTS", 0, 3, 0, MFLG_SLOW, 0,
  {m_unregistered, m_ignore, m_channelts},
  NULL, NULL
};

/*
 * m_channelts
 * parv[1] == channel name
 * parv[2] == remote timestamp
 */
int
m_channelts(struct Client *cptr, struct Client *sptr, int parc, char *parv[])
{
  struct Channel *chptr;

  chptr = get_channel(sptr, parv[1], CREATE);
  chptr->remotets = atoi(parv[2]);

  /* Forward the CHANNELTS and locally clear/lock if the other side has a better image */
  if (chptr->remotets < chptr->channelts)
    {
      chptr->frozen_by = sptr;
      clear_channel_modes(sptr, chptr);
      sendto_serv_butone(cptr, ":%s CHANNELTS %s %s", me.name, chptr->chname,
			 parv[2]);
    }
  return 0;
}
